#line 2 "parser/lex.pn.C"

#line 4 "parser/lex.pn.C"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE pnrestart(pnin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int pnleng;

extern FILE *pnin, *pnout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pntext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up pntext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via pnrestart()), so that the user can continue scanning by
	 * just pointing pnin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when pntext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int pnleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow pnwrap()'s to do buffer switches
 * instead of setting up a fresh pnin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void pnrestart (FILE *input_file  );
void pn_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE pn_create_buffer (FILE *file,int size  );
void pn_delete_buffer (YY_BUFFER_STATE b  );
void pn_flush_buffer (YY_BUFFER_STATE b  );
void pnpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void pnpop_buffer_state (void );

static void pnensure_buffer_stack (void );
static void pn_load_buffer_state (void );
static void pn_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER pn_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE pn_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE pn_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE pn_scan_bytes (yyconst char *bytes,int len  );

void *pnalloc (yy_size_t  );
void *pnrealloc (void *,yy_size_t  );
void pnfree (void *  );

#define yy_new_buffer pn_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        pnensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pn_create_buffer(pnin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        pnensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            pn_create_buffer(pnin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define pnwrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *pnin = (FILE *) 0, *pnout = (FILE *) 0;

typedef int yy_state_type;

extern int pnlineno;

int pnlineno = 1;

extern char *pntext;
#define yytext_ptr pntext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up pntext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	pnleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 144
#define YY_END_OF_BUFFER 145
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[436] =
    {   0,
        0,    0,    0,    0,    2,    2,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  145,  143,   39,   40,  141,  126,  141,  141,
      113,  141,  141,  141,   98,   99,  141,  141,  141,  107,
      141,  143,  141,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      141,   43,    1,    2,    3,    4,   20,    7,   21,   19,
       20,   18,   18,   18,   18,   18,   18,   22,   23,   29,

        7,   28,   27,   29,   25,   26,   30,    7,   30,   31,
        7,   31,   34,    7,   33,   32,   34,   35,    7,   35,
       38,    7,   37,   38,   36,  106,  103,  105,  100,  101,
      102,  104,  112,  111,  112,  119,  120,  114,  119,  125,
      121,  122,  124,  123,  134,  133,  127,  135,  140,  136,
      137,  139,  138,   39,   91,   86,   89,   96,   41,   42,
       97,   94,   93,   87,   90,   82,   92,   95,  107,   88,
      108,  142,   83,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,   85,

        2,    3,    4,    5,    4,    6,    7,    9,    8,   18,
       18,   18,   18,   18,   18,   18,   18,   22,   24,   36,
      111,  110,  109,  118,  115,  116,  118,  134,  132,  128,
      129,  131,   42,   84,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,   45,   70,  107,   49,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,  107,    8,
       18,   18,   18,   18,   18,   18,   18,   18,  109,  115,
      117,  128,  130,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,   59,   81,   80,  107,

       71,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  107,  107,  107,  107,  107,  107,   18,   12,
       18,   18,   18,   18,   11,   18,   57,  107,  107,  107,
      107,  107,   44,  107,  107,  107,   72,   63,  107,  107,
      107,   64,  107,  107,  107,  107,  107,  107,  107,  107,
      107,   75,  107,  107,  107,  107,  107,   18,   13,   14,
       18,   18,   17,  107,   66,  107,   58,  107,  107,   76,
       78,  107,   56,   68,   47,  107,  107,   48,  107,  107,
      107,  107,   69,  107,  107,   46,   51,  107,   16,   15,
       18,  107,  107,  107,   55,  107,   73,  107,  107,   50,

       67,   53,  107,  107,  107,   10,  107,  107,   62,  107,
       52,  107,   65,  107,  107,  107,   74,  107,  107,  107,
      107,  107,   54,  107,   77,  107,  107,  107,  107,   79,
      107,   61,  107,   60,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    1,    7,    8,    9,   10,
       11,   12,    7,    7,    7,   13,   14,   15,   16,   16,
       16,   16,   16,   16,   16,   17,   17,    7,    7,   18,
       19,   20,    7,    1,   21,   21,   21,   21,   21,   21,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       23,   24,   25,   26,   27,    1,   28,   29,   30,   31,

       32,   33,   34,   35,   36,   37,   38,   39,   40,   41,
       42,   43,   44,   45,   46,   47,   48,   22,   49,   50,
       51,   22,    7,   52,    7,    7,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[53] =
    {   0,
        1,    1,    2,    1,    3,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    5,    5,    5,    1,    1,    1,
        5,    6,    1,    3,    1,    1,    6,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    1
    } ;

static yyconst flex_int16_t yy_base[464] =
    {   0,
        0,  765,    0,    0,   50,   51,   63,    0,  766,  765,
      114,  118,  122,  123,  124,  125,  138,  142,  140,  144,
      158,    0,  210,    0,  248,  267,   40,   43,  300,    0,
      263,  265,  133,  135,  338,  357,  268,  353,  270,  275,
      376,  395,  764, 2604,  761, 2604,  743, 2604, 2604,  738,
     2604,  734,  731,  141,  693, 2604,  342,  274,  344,    0,
      717,  738,  714,  692,  337,  706,  340,  709,  708,  699,
      372,  239,  686,  337,  685,  700,  347,  351,  690,  698,
      677, 2604, 2604,  725, 2604,  417, 2604,  725, 2604, 2604,
      386,    0,  694,  360,  342,  689,  683,    0, 2604, 2604,

      721, 2604, 2604,  403,  672, 2604, 2604,  717,  407, 2604,
      715,  418, 2604,  714, 2604, 2604,  421, 2604,  710,  422,
     2604,  709, 2604,  425,    0, 2604, 2604, 2604, 2604, 2604,
     2604, 2604, 2604,    0,  707, 2604, 2604, 2604,  435, 2604,
     2604, 2604, 2604, 2604,    0, 2604, 2604,  437, 2604, 2604,
     2604, 2604, 2604,  692, 2604, 2604, 2604, 2604, 2604,    0,
     2604, 2604,  673, 2604, 2604, 2604, 2604, 2604,    0, 2604,
     2604, 2604, 2604,  650,  646,  649,  661,  645,  394,  639,
      402,  639,  654,  487,  539,  591,  404,  643,  636,  654,
      639,  648,  406,  416,  650,  418,  635,  424,  649, 2604,

      673, 2604,  445, 2604,  453, 2604,  673, 2604,    0,    0,
      641,  627,  641,  427,  641,  629,  636,    0, 2604,    0,
        0, 2604,  663, 2604,  662, 2604,    0,    0, 2604,  658,
     2604,    0,    0, 2604,  619,  627,  596,  610,  593,  610,
      598,  609,  590,  607,  602,  601, 2604, 2604,  600, 2604,
      643,  695,  747,  799,  601,  587,  581,  596,  595,  596,
      421,  429,  584,  592,  591,  590,  579,  584,  581,    0,
      582,  583,  577,  580,  577,  568,  574,  558,  587,  586,
     2604,  585, 2604,  851,  549,  537,  544,  531,  542,  903,
      541,  547,  539,  955, 1007,  532, 2604, 2604, 2604,  530,

     2604,  543, 1059,  542,  543,  544,  533,  529,  539,  536,
      535,  520, 1111,  532,  528,  519,  517,  516,  513,    0,
      505,  504,  504,  487,    0,  501, 2604,  492, 1163,  490,
     1215,  499, 2604,  484, 1267, 1319, 2604, 2604,  483, 1371,
     1423, 2604, 1475,  481,  481, 1527,  492,  478,  477,  476,
     1579, 2604,  490,  485, 1631, 1683,  469,  487,    0,    0,
      485,  486,    0,  488, 2604,  485, 2604,  483, 1735, 2604,
     2604,  479, 2604, 2604, 2604, 1787,  477, 2604,  469, 1839,
     1891, 1943, 2604,  471,  462, 2604, 2604,  475,    0,    0,
      454,  445,  445, 1995, 2604,  452, 2604, 2047,  430, 2604,

     2604, 2604, 2099,  448,  446,    0,  442, 2151, 2604,  430,
     2604,  449, 2604,  443,  445,  425, 2604, 2203,  431, 2255,
      426,  363, 2604,  329, 2604,  225, 2307,  121, 2359, 2604,
       77, 2604, 2411, 2604, 2604, 2463, 2469, 2475, 2481, 2487,
     2493, 2499, 2505, 2511, 2517, 2523, 2529, 2531, 2537, 2543,
     2549, 2551, 2557, 2559, 2561, 2567, 2573, 2579, 2585, 2591,
     2597,  113,   56
    } ;

static yyconst flex_int16_t yy_def[464] =
    {   0,
      435,    1,  436,  436,  437,  437,  435,    7,  438,  438,
      439,  439,  440,  440,  441,  441,  442,  442,  443,  443,
      435,   21,  435,   23,   23,   23,   23,   23,  435,   29,
      444,  444,  445,  445,  445,  445,  446,  446,  447,  447,
      447,  447,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  448,
      435,  449,  435,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  448,  448,  448,  448,
      435,  435,  435,  450,  435,  451,  435,  435,  435,  435,
      435,  452,  452,  452,  452,  452,  452,  453,  435,  435,

      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  454,  435,  435,  435,  435,  435,
      435,  435,  435,  455,  456,  435,  435,  435,  457,  435,
      435,  435,  435,  435,  458,  435,  435,  459,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  460,
      435,  435,  435,  435,  435,  435,  435,  435,  448,  435,
      435,  435,  435,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  448,  448,  448,  435,

      450,  435,  451,  435,  451,  435,  435,  435,  461,  452,
      452,  452,  452,  452,  452,  452,  452,  453,  435,  454,
      455,  435,  435,  435,  435,  435,  462,  458,  435,  435,
      435,  463,  460,  435,  448,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  435,  435,  448,  435,
      448,  448,  448,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  448,  448,  448,  461,
      452,  452,  452,  452,  452,  452,  452,  452,  435,  435,
      435,  435,  435,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  435,  435,  435,  448,

      435,  448,  448,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  448,  448,  452,  452,
      452,  452,  452,  452,  452,  452,  435,  448,  448,  448,
      448,  448,  435,  448,  448,  448,  435,  435,  448,  448,
      448,  435,  448,  448,  448,  448,  448,  448,  448,  448,
      448,  435,  448,  448,  448,  448,  448,  452,  452,  452,
      452,  452,  452,  448,  435,  448,  435,  448,  448,  435,
      435,  448,  435,  435,  435,  448,  448,  435,  448,  448,
      448,  448,  435,  448,  448,  435,  435,  448,  452,  452,
      452,  448,  448,  448,  435,  448,  435,  448,  448,  435,

      435,  435,  448,  448,  448,  452,  448,  448,  435,  448,
      435,  448,  435,  448,  448,  448,  435,  448,  448,  448,
      448,  448,  435,  448,  435,  448,  448,  448,  448,  435,
      448,  435,  448,  435,    0,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435
    } ;

static yyconst flex_int16_t yy_nxt[2657] =
    {   0,
       44,   45,   46,   47,   48,   49,   49,   50,   51,   52,
       49,   49,   53,   54,   55,   56,   56,   57,   58,   59,
       60,   60,   61,   62,   49,   63,   60,   64,   60,   65,
       66,   67,   68,   69,   70,   71,   60,   60,   60,   72,
       60,   73,   74,   75,   76,   77,   78,   79,   80,   60,
       60,   81,   85,   85,  132,  132,  132,  132,  132,  132,
      283,   86,   86,   87,   88,   89,   90,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   91,   87,   87,   87,
       87,   87,   87,   92,   92,   87,   87,   87,   87,   92,
       92,   92,   92,   93,   94,   92,   92,   92,   95,   92,

       92,   96,   92,   92,   92,   92,   92,   92,   92,   92,
       97,   92,   92,   92,   87,  101,  102,  281,  103,  101,
      102,  433,  103,  108,  108,  111,  111,  104,  105,  106,
      106,  104,  105,  106,  106,  109,  109,  112,  112,  114,
      115,  119,  116,  114,  115,  119,  116,  141,  141,  141,
      141,  117,  159,  120,  160,  117,  431,  120,  121,  122,
      123,  121,  121,  121,  121,  121,  121,  121,  121,  121,
      121,  124,  121,  121,  121,  121,  121,  121,  125,  125,
      121,  121,  121,  121,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,

      125,  125,  125,  125,  125,  125,  125,  125,  125,  121,
      126,  126,  126,  126,  126,  126,  126,  126,  126,  126,
      126,  126,  126,  126,  127,  127,  128,  126,  126,  126,
      128,  128,  126,  126,  126,  126,  128,  128,  128,  128,
      128,  128,  128,  128,  128,  128,  128,  128,  128,  128,
      128,  128,  128,  128,  128,  128,  128,  128,  128,  128,
      128,  126,  129,  129,  129,  137,  187,  137,  130,  429,
      146,  138,  147,  138,  188,  131,  131,  131,  131,  131,
      131,  129,  129,  129,  150,  150,  139,  130,  139,  150,
      150,  148,  165,  166,  131,  131,  131,  131,  131,  131,

      133,  133,  133,  133,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  134,  134,  134,  133,  133,  133,
      134,  134,  133,  135,  133,  133,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  133,  142,  142,  142,  146,  428,  147,  143,  162,
      163,  164,  167,  168,  175,  144,  144,  144,  144,  144,
      144,  142,  142,  142,  214,  190,  148,  143,  176,  178,
      179,  191,  215,  180,  144,  144,  144,  144,  144,  144,
      151,  151,  151,  194,  195,  196,  152,  208,  212,  209,

      213,  197,  184,  153,  153,  153,  153,  153,  153,  151,
      151,  151,  185,  427,  208,  152,  209,  186,  208,  204,
      209,  240,  153,  153,  153,  153,  153,  153,  205,  208,
      206,  209,  208,  208,  209,  209,  208,  225,  209,  230,
      243,  241,  258,  260,  259,  263,  251,  204,  244,  226,
      226,  231,  231,  252,  266,  204,  435,  274,  435,  267,
      261,  426,  308,  424,  205,  264,  206,  275,  309,  310,
      268,  422,  421,  420,  311,  419,  418,  416,  415,  414,
      412,  410,  408,  407,  227,  406,  232,  247,  247,  247,
      247,  247,  247,  247,  247,  247,  247,  247,  247,  247,

      247,  405,  404,  403,  247,  247,  247,  399,  398,  247,
      396,  247,  247,  394,  393,  392,  391,  390,  389,  388,
      385,  384,  382,  381,  380,  379,  377,  376,  372,  369,
      368,  366,  364,  363,  362,  361,  360,  359,  247,  248,
      248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
      248,  248,  248,  358,  357,  356,  248,  248,  248,  355,
      354,  248,  353,  248,  248,  351,  350,  349,  348,  347,
      346,  345,  344,  343,  341,  340,  339,  336,  335,  334,
      332,  331,  330,  329,  328,  249,  282,  280,  279,  326,
      248,  250,  250,  250,  250,  250,  250,  250,  250,  250,

      250,  250,  250,  250,  250,  325,  324,  323,  250,  250,
      250,  322,  321,  250,  320,  250,  250,  319,  318,  317,
      316,  315,  314,  313,  312,  307,  306,  305,  304,  303,
      302,  296,  295,  294,  293,  292,  291,  290,  289,  288,
      287,  286,  250,  297,  297,  297,  297,  297,  297,  297,
      297,  297,  297,  297,  297,  297,  297,  285,  284,  282,
      297,  297,  297,  280,  279,  297,  278,  297,  297,  277,
      276,  273,  272,  271,  207,  202,  269,  265,  262,  257,
      256,  255,  254,  253,  246,  245,  242,  239,  238,  237,
      236,  235,  234,  154,  297,  298,  298,  298,  298,  298,

      298,  298,  298,  298,  298,  298,  298,  298,  298,  223,
      207,  207,  298,  298,  298,  207,  207,  298,  207,  298,
      298,  219,  207,  217,  216,  211,  207,  202,  200,  199,
      198,  193,  192,  189,  183,  182,  181,  177,  174,  173,
      172,  170,  161,  158,  157,  156,  298,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  155,  154,  435,  299,  299,  299,   99,   99,  299,
       82,  299,  299,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  300,  435,  435,  435,  299,  301,

      301,  301,  301,  301,  301,  301,  301,  301,  301,  301,
      301,  301,  301,  435,  435,  435,  301,  301,  301,  435,
      435,  301,  435,  301,  301,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      301,  327,  327,  327,  327,  327,  327,  327,  327,  327,
      327,  327,  327,  327,  327,  435,  435,  435,  327,  327,
      327,  435,  435,  327,  435,  327,  327,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  327,  333,  333,  333,  333,  333,  333,  333,
      333,  333,  333,  333,  333,  333,  333,  435,  435,  435,
      333,  333,  333,  435,  435,  333,  435,  333,  333,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  333,  337,  337,  337,  337,  337,
      337,  337,  337,  337,  337,  337,  337,  337,  337,  435,
      435,  435,  337,  337,  337,  435,  435,  337,  435,  337,
      337,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  435,  435,  435,  435,  337,  338,  338,  338,
      338,  338,  338,  338,  338,  338,  338,  338,  338,  338,
      338,  435,  435,  435,  338,  338,  338,  435,  435,  338,
      435,  338,  338,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  338,  342,
      342,  342,  342,  342,  342,  342,  342,  342,  342,  342,
      342,  342,  342,  435,  435,  435,  342,  342,  342,  435,
      435,  342,  435,  342,  342,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      342,  352,  352,  352,  352,  352,  352,  352,  352,  352,
      352,  352,  352,  352,  352,  435,  435,  435,  352,  352,
      352,  435,  435,  352,  435,  352,  352,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  352,  365,  365,  365,  365,  365,  365,  365,
      365,  365,  365,  365,  365,  365,  365,  435,  435,  435,
      365,  365,  365,  435,  435,  365,  435,  365,  365,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  365,  367,  367,  367,  367,  367,
      367,  367,  367,  367,  367,  367,  367,  367,  367,  435,
      435,  435,  367,  367,  367,  435,  435,  367,  435,  367,
      367,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  367,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  435,  435,  435,  370,  370,  370,  435,  435,  370,
      435,  370,  370,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  370,  371,
      371,  371,  371,  371,  371,  371,  371,  371,  371,  371,
      371,  371,  371,  435,  435,  435,  371,  371,  371,  435,
      435,  371,  435,  371,  371,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      371,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  435,  435,  435,  373,  373,
      373,  435,  435,  373,  435,  373,  373,  435,  435,  435,

      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  373,  374,  374,  374,  374,  374,  374,  374,
      374,  374,  374,  374,  374,  374,  374,  435,  435,  435,
      374,  374,  374,  435,  435,  374,  435,  374,  374,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  374,  375,  375,  375,  375,  375,
      375,  375,  375,  375,  375,  375,  375,  375,  375,  435,
      435,  435,  375,  375,  375,  435,  435,  375,  435,  375,

      375,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  375,  378,  378,  378,
      378,  378,  378,  378,  378,  378,  378,  378,  378,  378,
      378,  435,  435,  435,  378,  378,  378,  435,  435,  378,
      435,  378,  378,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  378,  383,
      383,  383,  383,  383,  383,  383,  383,  383,  383,  383,
      383,  383,  383,  435,  435,  435,  383,  383,  383,  435,

      435,  383,  435,  383,  383,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      383,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  435,  435,  435,  386,  386,
      386,  435,  435,  386,  435,  386,  386,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  386,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  435,  435,  435,

      387,  387,  387,  435,  435,  387,  435,  387,  387,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  387,  395,  395,  395,  395,  395,
      395,  395,  395,  395,  395,  395,  395,  395,  395,  435,
      435,  435,  395,  395,  395,  435,  435,  395,  435,  395,
      395,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  395,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,

      397,  435,  435,  435,  397,  397,  397,  435,  435,  397,
      435,  397,  397,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  397,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  435,  435,  435,  400,  400,  400,  435,
      435,  400,  435,  400,  400,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      400,  401,  401,  401,  401,  401,  401,  401,  401,  401,

      401,  401,  401,  401,  401,  435,  435,  435,  401,  401,
      401,  435,  435,  401,  435,  401,  401,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  401,  402,  402,  402,  402,  402,  402,  402,
      402,  402,  402,  402,  402,  402,  402,  435,  435,  435,
      402,  402,  402,  435,  435,  402,  435,  402,  402,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  402,  409,  409,  409,  409,  409,

      409,  409,  409,  409,  409,  409,  409,  409,  409,  435,
      435,  435,  409,  409,  409,  435,  435,  409,  435,  409,
      409,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  409,  411,  411,  411,
      411,  411,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  435,  435,  435,  411,  411,  411,  435,  435,  411,
      435,  411,  411,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  411,  413,

      413,  413,  413,  413,  413,  413,  413,  413,  413,  413,
      413,  413,  413,  435,  435,  435,  413,  413,  413,  435,
      435,  413,  435,  413,  413,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      413,  417,  417,  417,  417,  417,  417,  417,  417,  417,
      417,  417,  417,  417,  417,  435,  435,  435,  417,  417,
      417,  435,  435,  417,  435,  417,  417,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  417,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  435,  435,  435,
      423,  423,  423,  435,  435,  423,  435,  423,  423,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  423,  425,  425,  425,  425,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  435,
      435,  435,  425,  425,  425,  435,  435,  425,  435,  425,
      425,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  435,  435,  435,  435,  425,  430,  430,  430,
      430,  430,  430,  430,  430,  430,  430,  430,  430,  430,
      430,  435,  435,  435,  430,  430,  430,  435,  435,  430,
      435,  430,  430,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  430,  432,
      432,  432,  432,  432,  432,  432,  432,  432,  432,  432,
      432,  432,  432,  435,  435,  435,  432,  432,  432,  435,
      435,  432,  435,  432,  432,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      432,  434,  434,  434,  434,  434,  434,  434,  434,  434,
      434,  434,  434,  434,  434,  435,  435,  435,  434,  434,
      434,  435,  435,  434,  435,  434,  434,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  434,   83,   83,   83,   83,   83,   83,   84,
       84,   84,   84,   84,   84,   98,   98,   98,   98,   98,
       98,  100,  100,  100,  100,  100,  100,  107,  107,  107,
      107,  107,  107,  110,  110,  110,  110,  110,  110,  113,

      113,  113,  113,  113,  113,  118,  118,  118,  118,  118,
      118,  136,  136,  136,  136,  136,  136,  140,  140,  140,
      140,  140,  140,  145,  145,  145,  145,  145,  145,  149,
      149,  149,  149,  149,  149,  169,  169,  171,  171,  171,
      171,  171,  171,  201,  201,  201,  435,  201,  201,  203,
      203,  203,  203,  203,  203,  210,  210,  218,  435,  218,
      218,  218,  218,  220,  220,  221,  221,  222,  222,  222,
      222,  222,  222,  224,  224,  224,  224,  224,  224,  228,
      435,  435,  228,  228,  228,  229,  229,  229,  229,  229,
      229,  233,  435,  233,  233,  233,  233,  270,  435,  270,

      270,  270,  270,   43,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435
    } ;

static yyconst flex_int16_t yy_chk[2657] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    6,   27,   27,   27,   28,   28,   28,
      463,    5,    6,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,

        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,   11,   11,  462,   11,   12,
       12,  431,   12,   13,   14,   15,   16,   11,   11,   11,
       11,   12,   12,   12,   12,   13,   14,   15,   16,   17,
       17,   19,   17,   18,   18,   20,   18,   33,   33,   34,
       34,   17,   54,   19,   54,   18,  428,   20,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,

       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   25,   25,   25,   31,   72,   32,   25,  426,
       37,   31,   37,   32,   72,   25,   25,   25,   25,   25,
       25,   26,   26,   26,   39,   39,   31,   26,   32,   40,
       40,   37,   58,   58,   26,   26,   26,   26,   26,   26,

       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   35,   35,   35,   38,  424,   38,   35,   57,
       57,   57,   59,   59,   65,   35,   35,   35,   35,   35,
       35,   36,   36,   36,   95,   74,   38,   36,   65,   67,
       67,   74,   95,   67,   36,   36,   36,   36,   36,   36,
       41,   41,   41,   77,   77,   78,   41,   91,   94,   91,

       94,   78,   71,   41,   41,   41,   41,   41,   41,   42,
       42,   42,   71,  422,  104,   42,  104,   71,  109,   86,
      109,  179,   42,   42,   42,   42,   42,   42,   86,  112,
       86,  112,  117,  120,  117,  120,  124,  139,  124,  148,
      181,  179,  193,  194,  193,  196,  187,  203,  181,  139,
      139,  148,  148,  187,  198,  205,  203,  214,  203,  198,
      194,  421,  261,  419,  205,  196,  205,  214,  261,  262,
      198,  416,  415,  414,  262,  412,  410,  407,  405,  404,
      399,  396,  393,  392,  139,  391,  148,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  184,  184,  184,

      184,  388,  385,  384,  184,  184,  184,  379,  377,  184,
      372,  184,  184,  368,  366,  364,  362,  361,  358,  357,
      354,  353,  350,  349,  348,  347,  345,  344,  339,  334,
      332,  330,  328,  326,  324,  323,  322,  321,  184,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  319,  318,  317,  185,  185,  185,  316,
      315,  185,  314,  185,  185,  312,  311,  310,  309,  308,
      307,  306,  305,  304,  302,  300,  296,  293,  292,  291,
      289,  288,  287,  286,  285,  185,  282,  280,  279,  278,
      185,  186,  186,  186,  186,  186,  186,  186,  186,  186,

      186,  186,  186,  186,  186,  277,  276,  275,  186,  186,
      186,  274,  273,  186,  272,  186,  186,  271,  269,  268,
      267,  266,  265,  264,  263,  260,  259,  258,  257,  256,
      255,  249,  246,  245,  244,  243,  242,  241,  240,  239,
      238,  237,  186,  251,  251,  251,  251,  251,  251,  251,
      251,  251,  251,  251,  251,  251,  251,  236,  235,  230,
      251,  251,  251,  225,  223,  251,  217,  251,  251,  216,
      215,  213,  212,  211,  207,  201,  199,  197,  195,  192,
      191,  190,  189,  188,  183,  182,  180,  178,  177,  176,
      175,  174,  163,  154,  251,  252,  252,  252,  252,  252,

      252,  252,  252,  252,  252,  252,  252,  252,  252,  135,
      122,  119,  252,  252,  252,  114,  111,  252,  108,  252,
      252,  105,  101,   97,   96,   93,   88,   84,   81,   80,
       79,   76,   75,   73,   70,   69,   68,   66,   64,   63,
       62,   61,   55,   53,   52,   50,  252,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,   47,   45,   43,  253,  253,  253,   10,    9,  253,
        2,  253,  253,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  253,    0,    0,    0,  253,  254,

      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,    0,    0,    0,  254,  254,  254,    0,
        0,  254,    0,  254,  254,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      254,  284,  284,  284,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  284,    0,    0,    0,  284,  284,
      284,    0,    0,  284,    0,  284,  284,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,  284,  290,  290,  290,  290,  290,  290,  290,
      290,  290,  290,  290,  290,  290,  290,    0,    0,    0,
      290,  290,  290,    0,    0,  290,    0,  290,  290,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  290,  294,  294,  294,  294,  294,
      294,  294,  294,  294,  294,  294,  294,  294,  294,    0,
        0,    0,  294,  294,  294,    0,    0,  294,    0,  294,
      294,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  294,  295,  295,  295,
      295,  295,  295,  295,  295,  295,  295,  295,  295,  295,
      295,    0,    0,    0,  295,  295,  295,    0,    0,  295,
        0,  295,  295,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  295,  303,
      303,  303,  303,  303,  303,  303,  303,  303,  303,  303,
      303,  303,  303,    0,    0,    0,  303,  303,  303,    0,
        0,  303,    0,  303,  303,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      303,  313,  313,  313,  313,  313,  313,  313,  313,  313,
      313,  313,  313,  313,  313,    0,    0,    0,  313,  313,
      313,    0,    0,  313,    0,  313,  313,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  313,  329,  329,  329,  329,  329,  329,  329,
      329,  329,  329,  329,  329,  329,  329,    0,    0,    0,
      329,  329,  329,    0,    0,  329,    0,  329,  329,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  329,  331,  331,  331,  331,  331,
      331,  331,  331,  331,  331,  331,  331,  331,  331,    0,
        0,    0,  331,  331,  331,    0,    0,  331,    0,  331,
      331,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  331,  335,  335,  335,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,    0,    0,    0,  335,  335,  335,    0,    0,  335,
        0,  335,  335,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  335,  336,
      336,  336,  336,  336,  336,  336,  336,  336,  336,  336,
      336,  336,  336,    0,    0,    0,  336,  336,  336,    0,
        0,  336,    0,  336,  336,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      336,  340,  340,  340,  340,  340,  340,  340,  340,  340,
      340,  340,  340,  340,  340,    0,    0,    0,  340,  340,
      340,    0,    0,  340,    0,  340,  340,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  340,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,    0,    0,    0,
      341,  341,  341,    0,    0,  341,    0,  341,  341,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  341,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,    0,
        0,    0,  343,  343,  343,    0,    0,  343,    0,  343,

      343,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  343,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,    0,    0,    0,  346,  346,  346,    0,    0,  346,
        0,  346,  346,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  346,  351,
      351,  351,  351,  351,  351,  351,  351,  351,  351,  351,
      351,  351,  351,    0,    0,    0,  351,  351,  351,    0,

        0,  351,    0,  351,  351,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      351,  355,  355,  355,  355,  355,  355,  355,  355,  355,
      355,  355,  355,  355,  355,    0,    0,    0,  355,  355,
      355,    0,    0,  355,    0,  355,  355,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  355,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,    0,    0,    0,

      356,  356,  356,    0,    0,  356,    0,  356,  356,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  356,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,  369,    0,
        0,    0,  369,  369,  369,    0,    0,  369,    0,  369,
      369,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  369,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,

      376,    0,    0,    0,  376,  376,  376,    0,    0,  376,
        0,  376,  376,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  376,  380,
      380,  380,  380,  380,  380,  380,  380,  380,  380,  380,
      380,  380,  380,    0,    0,    0,  380,  380,  380,    0,
        0,  380,    0,  380,  380,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      380,  381,  381,  381,  381,  381,  381,  381,  381,  381,

      381,  381,  381,  381,  381,    0,    0,    0,  381,  381,
      381,    0,    0,  381,    0,  381,  381,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  381,  382,  382,  382,  382,  382,  382,  382,
      382,  382,  382,  382,  382,  382,  382,    0,    0,    0,
      382,  382,  382,    0,    0,  382,    0,  382,  382,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  382,  394,  394,  394,  394,  394,

      394,  394,  394,  394,  394,  394,  394,  394,  394,    0,
        0,    0,  394,  394,  394,    0,    0,  394,    0,  394,
      394,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  394,  398,  398,  398,
      398,  398,  398,  398,  398,  398,  398,  398,  398,  398,
      398,    0,    0,    0,  398,  398,  398,    0,    0,  398,
        0,  398,  398,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  398,  403,

      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,    0,    0,    0,  403,  403,  403,    0,
        0,  403,    0,  403,  403,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      403,  408,  408,  408,  408,  408,  408,  408,  408,  408,
      408,  408,  408,  408,  408,    0,    0,    0,  408,  408,
      408,    0,    0,  408,    0,  408,  408,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,  408,  418,  418,  418,  418,  418,  418,  418,
      418,  418,  418,  418,  418,  418,  418,    0,    0,    0,
      418,  418,  418,    0,    0,  418,    0,  418,  418,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  418,  420,  420,  420,  420,  420,
      420,  420,  420,  420,  420,  420,  420,  420,  420,    0,
        0,    0,  420,  420,  420,    0,    0,  420,    0,  420,
      420,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  420,  427,  427,  427,
      427,  427,  427,  427,  427,  427,  427,  427,  427,  427,
      427,    0,    0,    0,  427,  427,  427,    0,    0,  427,
        0,  427,  427,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  427,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,    0,    0,    0,  429,  429,  429,    0,
        0,  429,    0,  429,  429,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      429,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  433,  433,    0,    0,    0,  433,  433,
      433,    0,    0,  433,    0,  433,  433,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  433,  436,  436,  436,  436,  436,  436,  437,
      437,  437,  437,  437,  437,  438,  438,  438,  438,  438,
      438,  439,  439,  439,  439,  439,  439,  440,  440,  440,
      440,  440,  440,  441,  441,  441,  441,  441,  441,  442,

      442,  442,  442,  442,  442,  443,  443,  443,  443,  443,
      443,  444,  444,  444,  444,  444,  444,  445,  445,  445,
      445,  445,  445,  446,  446,  446,  446,  446,  446,  447,
      447,  447,  447,  447,  447,  448,  448,  449,  449,  449,
      449,  449,  449,  450,  450,  450,    0,  450,  450,  451,
      451,  451,  451,  451,  451,  452,  452,  453,    0,  453,
      453,  453,  453,  454,  454,  455,  455,  456,  456,  456,
      456,  456,  456,  457,  457,  457,  457,  457,  457,  458,
        0,    0,  458,  458,  458,  459,  459,  459,  459,  459,
      459,  460,    0,  460,  460,  460,  460,  461,    0,  461,

      461,  461,  461,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int pn_flex_debug;
int pn_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *pntext;
#line 1 "parser/maria.lex"
/* -*- c++ -*- Scanner for Maria's Petri Net language */
#define YY_NO_INPUT 1
#line 21 "parser/maria.lex"
# include <stdio.h>
# include <limits.h>
# include <string.h>

# include "typedefs.h"
# include "maria.tab.h"

# include "StringBuffer.h"
# include "util.h"
# include "NameList.h"

  /** @file maria.lex
   * Lexical analyser for the modelling language
   */

  /* Copyright © 1998-2003 Marko Mäkelä (msmakela@tcs.hut.fi).

  This file is part of MARIA, a reachability analyzer and model checker
  for high-level Petri nets.

  MARIA is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.

  MARIA is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  The GNU General Public License is often shipped with GNU software, and
  is generally kept in a file called COPYING or LICENSE.  If you do not
  have a copy of the license, write to the Free Software Foundation,
  59 Temple Place, Suite 330, Boston, MA 02111 USA. */

# include <stack>
  /** Stack of include files */
  struct input
  {
    /** name of the input file */
    class StringBuffer* name;
    /** input line number */
    unsigned lineno;
    /** number of unterminated preprocessor #if statements */
    unsigned condlevel;
    /** buffer state */
    YY_BUFFER_STATE bs;
  };
  static std::stack<struct input, std::list<struct input> > in;
  /** Current preprocessor condition directive */
  static enum { none, ifdef, ifndef, define, undef } currentDirective;
  /** Set of defined preprocessor conditions */
  static class NameList defs;
  /** preprocessor #if nesting level */
  static unsigned condlevel = 0;
  /** deepest #if nesting level where #else has an effect */
  static unsigned passlevel = 0;
  /** flag: pass tokens to the parser (instead of eating them up) */
  static bool pass = true;
  /** conditionally ignore the input */
# define I if (assert (!pass || condlevel == passlevel), !pass) break

  /** Dynamically growing string buffer */
  static class StringBuffer sbuf;
  /** @name String handling macros.  All of these use sbuf. */
  /*@{*/
# define CREAT memcpy (sbuf.create (pnleng), pntext, pnleng + 1)
# define INITSTR sbuf.create (0)
# define EXTEND do {						\
    unsigned len = sbuf.getLength ();				\
    memcpy (sbuf.extend (pnleng) + len, pntext, pnleng + 1);	\
  } while (0)
# define APPEND(c) do {				\
    unsigned len = sbuf.getLength ();		\
    (&((sbuf.extend (1))[len] = c))[1] = 0;	\
  } while (0)
# define COPY							\
  (strlen (pnlval.s = sbuf.copy ()) == sbuf.getLength ()) ||	\
  (pnerror ("truncating name containing NUL chars"), 0)
  /*@}*/

  /** @name Start condition stack handling */
  /*@{*/
# define SC_FLUSH	yy_start_stack_ptr = 0, BEGIN (INITIAL)
# define SC_POP		yy_pop_state ()
# define SC_POP_B	do { SC_POP; yyless (0); } while (0)
# define SC_PUSH(s)	yy_push_state (s)
# define SC_SWITCH(s)	BEGIN (s)
# define SC_SWITCH_B(s)	do { yyless (0); SC_SWITCH (s); } while (0)
# define SC_CALL(s,r)	do { rt = r; SC_PUSH (ret); SC_PUSH (s); } while (0)
# define SC_USE(s,r)	do { SC_SWITCH (r); SC_PUSH (s); } while (0)
  /*@}*/

  /** initial source file name */
  extern const char* netname;

  /** source file line number */
  static unsigned lineno = 1;
  /** source file name */
  static class StringBuffer filename;

  /** Token to be returned to the parser */
  static int rt;
  /** Flag: input constant overflow */
  static bool overflow = false;
  /** Number of digits read in an octal or hexadecimal character constant */
  static unsigned digits = 0;
  /** Character constant being parsed in a string */
  static char character;

  /** Reset the lexical analyzer */
  void pnlexreset (void);

  /** warning flag (true=print warnings) */
  bool pnwarnings = true;
  /** number of errors encountered */
  unsigned pnerrors = 0;

  /** The place that is currently being processed */
  extern class Place* currentPlace;
  class Net;
# include "Place.h"
  /** The transition that is currently being processed */
  extern class Transition* currentTransition;
# include "Transition.h"

  /**
   * display a message prefix at beginning of line
   * @return		number of characters written
   */
  unsigned pnmsg (void);

  /**
   * generic compiler warning reporting function
   * @param s		warning message
   */
  void pnwarn (const char* s);

  /**
   * generic parser error reporting function
   * @param s		error message
   */
  void pnerror (const char* s);

  /** Open an input file.
   * @param name	name of the input file
   * @return		a descriptor to the file, or NULL on error
   */
  extern FILE* openfile (const char* name);
  /** Switch files on EOF (return to the file that included the current file)
   * @return	true if there was a parent file
   */
  static bool popInclude (void);

  /** Check whether a preprocessor symbol is defined
   * @param sym		name of the symbol
   * @return		whether the symbol is defined
   */
  bool defined (const char* sym);
  /** Define a preprocessor symbol
   * @param sym		name of the symbol
   */
  void define_sym (const char* sym);
  /** Undefine a preprocessor symbol
   * @param sym		name of the symbol
   */
  void undef_sym (const char* sym);

  /** Advance to next buffer */
# define NEXTBUF do if (!popInclude ()) { SC_FLUSH; yyterminate (); } while (0)
  /** User-defined lexical analyser initialisation */
# define YY_USER_INIT NEXTBUF

  /** Read more input */
# define YY_INPUT(buf,result,max_size)					\
  if (!pnin && !popInclude ()) result = 0, pnlexreset ();		\
  else if (!(result = fread (buf, 1, max_size, pnin)) && ferror (pnin))	\
    pnerror ("input error"), pnlexreset ()
/* Start conditions */
/* returning to the parser */

/* inside a comment */

/* parsing a preprocessor directive */

/* parsing a preprocessor directive, ignoring the rest of the line */

/* parsing a preprocessor directive "line" */

/* parsing a preprocessor directive "line", got line number */

/* parsing a preprocessor directive "line", got file name */

/* parsing a preprocessor directive "include" */

/* parsing a preprocessor directive "include", got file name */

/* parsing a preprocessor condition name */

/* parsing an octal constant */

/* parsing a hexadecimal constant */

/* parsing a decimal constant */

/* parsing a name */

/* parsing a character constant */

/* parsing an octal character constant */

/* parsing a hexadecimal character constant */

/* parsing a string constant */

/* parsing an octal character constant in a string */

/* parsing a hexadecimal character constant in a string */

#line 1401 "parser/lex.pn.C"

#define INITIAL 0
#define ret 1
#define comment 2
#define pr 3
#define pr_ignore 4
#define pr_line 5
#define pr_line_number 6
#define pr_line_name 7
#define pr_incl 8
#define pr_incl_name 9
#define pr_cond 10
#define octal 11
#define hexadecimal 12
#define decimal 13
#define pnname 14
#define pnchar 15
#define pnchar_oct 16
#define pnchar_hex 17
#define pnstring 18
#define pnstring_oct 19
#define pnstring_hex 20

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int pnwrap (void );
#else
extern int pnwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = 0;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( pntext, pnleng, 1, pnout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( pnin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( pnin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, pnin))==0 && ferror(pnin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(pnin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int pnlex (void);

#define YY_DECL int pnlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after pntext and pnleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( pnleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(pntext[pnleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 249 "parser/maria.lex"


#line 1584 "parser/lex.pn.C"

	if ( (yy_init) )
		{
		(yy_init) = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! pnin )
			pnin = stdin;

		if ( ! pnout )
			pnout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			pnensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				pn_create_buffer(pnin,YY_BUF_SIZE );
		}

		pn_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of pntext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 436 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 435 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 251 "parser/maria.lex"
{ SC_POP_B; I; if (rt == NAME) COPY; return rt; }
	YY_BREAK
case YY_STATE_EOF(ret):
#line 252 "parser/maria.lex"
{ SC_POP; NEXTBUF; I; if (rt == NAME) COPY; return rt; }
	YY_BREAK

case 2:
YY_RULE_SETUP
#line 255 "parser/maria.lex"

	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 256 "parser/maria.lex"
lineno++;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 257 "parser/maria.lex"

	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 258 "parser/maria.lex"
lineno++;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 259 "parser/maria.lex"
SC_POP;
	YY_BREAK
case YY_STATE_EOF(comment):
#line 260 "parser/maria.lex"
{ pnerror ("EOF in comment"); SC_POP; NEXTBUF; }
	YY_BREAK


case 7:
YY_RULE_SETUP
#line 264 "parser/maria.lex"

	YY_BREAK
case 8:
YY_RULE_SETUP
#line 265 "parser/maria.lex"

	YY_BREAK
case 9:
YY_RULE_SETUP
#line 266 "parser/maria.lex"
SC_PUSH (comment);
	YY_BREAK
case YY_STATE_EOF(pr):
case YY_STATE_EOF(pr_line):
case YY_STATE_EOF(pr_line_number):
case YY_STATE_EOF(pr_line_name):
case YY_STATE_EOF(pr_incl):
case YY_STATE_EOF(pr_incl_name):
case YY_STATE_EOF(pr_cond):
#line 267 "parser/maria.lex"
{ SC_POP; NEXTBUF; }
	YY_BREAK


case 10:
YY_RULE_SETUP
#line 271 "parser/maria.lex"
SC_SWITCH (pr_incl);
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 272 "parser/maria.lex"
SC_SWITCH (pr_line);
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 273 "parser/maria.lex"
{
    if (!condlevel)
      pnerror ("#else without #if");
    else if (pass)
      assert (passlevel == condlevel), pass = false, passlevel--;
    else if (passlevel + 1 == condlevel)
      pass = true, passlevel++;
    else
      assert (passlevel < condlevel);
    currentDirective = none; SC_SWITCH (pr_cond);
  }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 284 "parser/maria.lex"
{
    if (!condlevel)
      pnerror ("#endif without #if");
    else if (passlevel >= --condlevel)
      pass = true, passlevel = condlevel;
    currentDirective = none; SC_SWITCH (pr_cond);
  }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 292 "parser/maria.lex"
{ currentDirective = ifdef; SC_SWITCH (pr_cond); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 293 "parser/maria.lex"
{ currentDirective = ifndef; SC_SWITCH (pr_cond); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 294 "parser/maria.lex"
{ currentDirective = define; SC_SWITCH (pr_cond); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 295 "parser/maria.lex"
{ currentDirective = undef; SC_SWITCH (pr_cond); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 297 "parser/maria.lex"
{
    pnerror ("unknown preprocessor directive");
    SC_SWITCH (pr_ignore);
  }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 301 "parser/maria.lex"
{
    SC_SWITCH (pr_ignore); /* #! interpreter command */
  }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 304 "parser/maria.lex"
{
    pnerror ("error in preprocessor directive"); SC_SWITCH (pr_ignore);
  }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 307 "parser/maria.lex"
{
    pnerror ("expected a preprocessor directive"); SC_POP; lineno++;
  }
	YY_BREAK


case 22:
YY_RULE_SETUP
#line 313 "parser/maria.lex"
SC_POP;
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 314 "parser/maria.lex"
{ SC_POP; lineno++; }
	YY_BREAK
case YY_STATE_EOF(pr_ignore):
#line 315 "parser/maria.lex"
{ SC_POP; NEXTBUF; }
	YY_BREAK


case 24:
YY_RULE_SETUP
#line 319 "parser/maria.lex"
{
    pnlval.i = 0, overflow = false;
    SC_USE (hexadecimal, pr_line_number);
  }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 323 "parser/maria.lex"
{
    pnlval.i = 0, overflow = false;
    SC_USE (octal, pr_line_number);
  }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 327 "parser/maria.lex"
{
    pnlval.i = *pntext - '0', overflow = false;
    SC_USE (decimal, pr_line_number);
  }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 331 "parser/maria.lex"
{ INITSTR; SC_USE (pnstring, pr_line_name); }
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 332 "parser/maria.lex"
{ lineno++; SC_POP; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 333 "parser/maria.lex"
{
    pnerror ("error in preprocessor directive #line");
    SC_SWITCH (pr_ignore);
  }
	YY_BREAK

case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 339 "parser/maria.lex"
{
  SC_SWITCH_B (pr_line);
  lineno = pnlval.i - 1;
}
	YY_BREAK
case 31:
/* rule 31 can match eol */
YY_RULE_SETUP
#line 344 "parser/maria.lex"
{ SC_SWITCH_B (pr_line); filename = sbuf; }
	YY_BREAK

case 32:
YY_RULE_SETUP
#line 347 "parser/maria.lex"
{ INITSTR; SC_USE (pnstring, pr_incl_name); }
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 348 "parser/maria.lex"
{
    pnerror ("unexceptedly terminated preprocessor directive #include");
    lineno++; SC_POP;
  }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 352 "parser/maria.lex"
{
    pnerror ("error in preprocessor directive #include");
    SC_SWITCH (pr_ignore);
  }
	YY_BREAK

case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 358 "parser/maria.lex"
{
  SC_POP_B; I;
  if (FILE* f = openfile (sbuf.getString ())) {
    struct input is = {
      new class StringBuffer (filename), lineno, condlevel, YY_CURRENT_BUFFER
    };
    in.push (is);
    filename = sbuf;
    lineno = 1;
    pn_switch_to_buffer (pn_create_buffer (f, YY_BUF_SIZE));
  }
  else {
    perror (sbuf.getString ());
    pnerror ("could not open include file");
  }
}
	YY_BREAK

case 36:
YY_RULE_SETUP
#line 376 "parser/maria.lex"
{
    switch (currentDirective) {
    case none:
      pnerror ("error in preprocessor directive"); SC_SWITCH (pr_ignore);
      break;
    case ifdef:
      condlevel++;
      if (pass) {
	if (!defined (pntext))
	  pass = false;
	else
	  passlevel = condlevel;
      }
      break;
    case ifndef:
      condlevel++;
      if (pass) {
	if (defined (pntext))
	  pass = false;
	else
	  passlevel = condlevel;
      }
      break;
    case define:
      if (pass) define_sym (pntext);
      break;
    case undef:
      if (pass) undef_sym (pntext);
      break;
    }
    currentDirective = none;
  }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 409 "parser/maria.lex"
{
    if (currentDirective != none)
      pnerror ("missing condition name");
    lineno++; SC_POP;
  }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 415 "parser/maria.lex"
{
    pnerror ("error in preprocessor condition directive");
    SC_SWITCH (pr_ignore);
  }
	YY_BREAK

case 39:
YY_RULE_SETUP
#line 421 "parser/maria.lex"

	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 422 "parser/maria.lex"
lineno++;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 423 "parser/maria.lex"
SC_PUSH (comment);
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 424 "parser/maria.lex"

	YY_BREAK
case 43:
YY_RULE_SETUP
#line 425 "parser/maria.lex"
SC_PUSH (pr);
	YY_BREAK
case 44:
/* rule 44 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 427 "parser/maria.lex"
{ I; return ENUM; }
	YY_BREAK
case 45:
/* rule 45 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 428 "parser/maria.lex"
{ I; return ID; }
	YY_BREAK
case 46:
/* rule 46 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 429 "parser/maria.lex"
{ I; return UNION; }
	YY_BREAK
case 47:
/* rule 47 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 430 "parser/maria.lex"
{ I; return QUEUE; }
	YY_BREAK
case 48:
/* rule 48 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 431 "parser/maria.lex"
{ I; return STACK; }
	YY_BREAK
case 49:
/* rule 49 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 432 "parser/maria.lex"
{ I; return IS; }
	YY_BREAK
case 50:
/* rule 50 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 433 "parser/maria.lex"
{ I; return STRUCT; }
	YY_BREAK
case 51:
/* rule 51 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 434 "parser/maria.lex"
{ I; return UNTIL; }
	YY_BREAK
case 52:
/* rule 52 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 7;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 435 "parser/maria.lex"
{ I; return RELEASE; }
	YY_BREAK
case 53:
/* rule 53 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 436 "parser/maria.lex"
{ I; return SUBSET; }
	YY_BREAK
case 54:
/* rule 54 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 9;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 437 "parser/maria.lex"
{ I; return INTERSECT; }
	YY_BREAK
case 55:
/* rule 55 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 438 "parser/maria.lex"
{ I; return EQUALS; }
	YY_BREAK
case 56:
/* rule 56 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 439 "parser/maria.lex"
{ I; return MINUS; }
	YY_BREAK
case 57:
/* rule 57 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 440 "parser/maria.lex"
{ I; return ATOM_; }
	YY_BREAK
case 58:
/* rule 58 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 441 "parser/maria.lex"
{ I; return EMPTY; }
	YY_BREAK
case 59:
/* rule 59 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 442 "parser/maria.lex"
{ I; return MAP; }
	YY_BREAK
case 60:
/* rule 60 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 13;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 443 "parser/maria.lex"
{ I; return SFAIR; }
	YY_BREAK
case 61:
/* rule 61 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 11;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 444 "parser/maria.lex"
{ I; return WFAIR; }
	YY_BREAK
case 62:
/* rule 62 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 7;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 445 "parser/maria.lex"
{ I; return ENABLED; }
	YY_BREAK
case 63:
/* rule 63 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 446 "parser/maria.lex"
{ I; return HIDE; }
	YY_BREAK
case 64:
/* rule 64 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 447 "parser/maria.lex"
{ I; return PROP; }
	YY_BREAK
case 65:
/* rule 65 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 7;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 449 "parser/maria.lex"
{ I; return TYPEDEF; }
	YY_BREAK
case 66:
/* rule 66 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 450 "parser/maria.lex"
{ I; return CONST_; }
	YY_BREAK
case 67:
/* rule 67 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 452 "parser/maria.lex"
{ I; return SUBNET; }
	YY_BREAK
case 68:
/* rule 68 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 453 "parser/maria.lex"
{ I; return PLACE; }
	YY_BREAK
case 69:
/* rule 69 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 454 "parser/maria.lex"
{ I; return TRANS; }
	YY_BREAK
case 70:
/* rule 70 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 455 "parser/maria.lex"
{ I; return IN_; }
	YY_BREAK
case 71:
/* rule 71 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 456 "parser/maria.lex"
{ I; return OUT_; }
	YY_BREAK
case 72:
/* rule 72 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 457 "parser/maria.lex"
{ I; return GATE; }
	YY_BREAK
case 73:
/* rule 73 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 458 "parser/maria.lex"
{ I; return REJECT_; }
	YY_BREAK
case 74:
/* rule 74 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 459 "parser/maria.lex"
{ I; return DEADLOCK; }
	YY_BREAK
case 75:
/* rule 75 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 460 "parser/maria.lex"
{ I; return TRUE_; }
	YY_BREAK
case 76:
/* rule 76 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 461 "parser/maria.lex"
{ I; return FALSE_; }
	YY_BREAK
case 77:
/* rule 77 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 9;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 462 "parser/maria.lex"
{ I; return UNDEFINED; }
	YY_BREAK
case 78:
/* rule 78 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 463 "parser/maria.lex"
{ I; return FATAL; }
	YY_BREAK
case 79:
/* rule 79 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 11;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 465 "parser/maria.lex"
{ I; return CARDINALITY; }
	YY_BREAK
case 80:
/* rule 80 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 466 "parser/maria.lex"
{ I; return MIN_; }
	YY_BREAK
case 81:
/* rule 81 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 467 "parser/maria.lex"
{ I; return MAX_; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 469 "parser/maria.lex"
{ I; return IMPL; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 470 "parser/maria.lex"
{ I; return XOR; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 471 "parser/maria.lex"
{ I; return EQUIV; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 472 "parser/maria.lex"
{ I; return OR; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 473 "parser/maria.lex"
{ I; return AND; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 474 "parser/maria.lex"
{ I; return FINALLY; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 475 "parser/maria.lex"
{ I; return GLOBALLY; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 476 "parser/maria.lex"
{ I; return NEXT; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 478 "parser/maria.lex"
{ I; return EQ; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 479 "parser/maria.lex"
{ I; return NE; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 480 "parser/maria.lex"
{ I; return GE; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 481 "parser/maria.lex"
{ I; return LE; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 482 "parser/maria.lex"
{ I; return ROL; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 483 "parser/maria.lex"
{ I; return ROR; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 484 "parser/maria.lex"
{ I; return RANGE; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 486 "parser/maria.lex"
{
  pnlval.i = 0, overflow = false; SC_CALL (hexadecimal, NUMBER);
}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 489 "parser/maria.lex"
{
  pnlval.i = 0, overflow = false; SC_CALL (octal, NUMBER);
}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 492 "parser/maria.lex"
{
  pnlval.i = *pntext - '0', overflow = false; SC_CALL (decimal, NUMBER);
}
	YY_BREAK

case 100:
YY_RULE_SETUP
#line 497 "parser/maria.lex"
{
    if (overflow);
    else if (pnlval.i > CARD_T_MAX >> 4)
      pnerror ("hexadecimal constant too large"), overflow = true;
    else
      (pnlval.i <<= 4) |= *pntext - '0';
  }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 504 "parser/maria.lex"
{
    if (overflow);
    else if (pnlval.i > CARD_T_MAX >> 4)
      pnerror ("hexadecimal constant too large"), overflow = true;
    else
      (pnlval.i <<= 4) |= *pntext - 'A' + 0x0A;
  }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 511 "parser/maria.lex"
{
    if (overflow);
    else if (pnlval.i > CARD_T_MAX >> 4)
      pnerror ("hexadecimal constant too large"), overflow = true;
    else
      (pnlval.i <<= 4) |= *pntext - 'a' + 0x0A;
  }
	YY_BREAK

case 103:
YY_RULE_SETUP
#line 520 "parser/maria.lex"
{
  if (overflow);
  else if (pnlval.i > CARD_T_MAX >> 3)
    pnerror ("octal constant too large"), overflow = true;
  else
    (pnlval.i <<= 3) |= *pntext - '0';
}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 528 "parser/maria.lex"
{
  if (!overflow) {
    card_t v = pnlval.i * 10 + (*pntext - '0');
    if (v / 10 != pnlval.i)
      pnerror ("decimal constant too large"), overflow = true;
    else
      pnlval.i = v;
  }
}
	YY_BREAK

case 105:
YY_RULE_SETUP
#line 539 "parser/maria.lex"
{
    pnerror ("improperly terminated numeric constant");
    yyless (0); SC_POP;
  }
	YY_BREAK
case 106:
/* rule 106 can match eol */
YY_RULE_SETUP
#line 543 "parser/maria.lex"
{
    yyless (0); SC_POP;
  }
	YY_BREAK
case YY_STATE_EOF(hexadecimal):
case YY_STATE_EOF(octal):
case YY_STATE_EOF(decimal):
#line 546 "parser/maria.lex"
{
    SC_POP; NEXTBUF;
  }
	YY_BREAK

case 107:
YY_RULE_SETUP
#line 551 "parser/maria.lex"
{ CREAT; SC_PUSH (pnname); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 552 "parser/maria.lex"
{ INITSTR; APPEND (pntext[1]); SC_PUSH (pnname); }
	YY_BREAK

case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
#line 555 "parser/maria.lex"
lineno++;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 556 "parser/maria.lex"
APPEND (pntext[1]);
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 557 "parser/maria.lex"
EXTEND;
	YY_BREAK
case 112:
/* rule 112 can match eol */
YY_RULE_SETUP
#line 558 "parser/maria.lex"
{ SC_POP_B; I; COPY; return NAME; }
	YY_BREAK

case 113:
YY_RULE_SETUP
#line 561 "parser/maria.lex"
{ overflow = false; SC_PUSH (pnchar); }
	YY_BREAK

case 114:
YY_RULE_SETUP
#line 564 "parser/maria.lex"
{
    if (!overflow) {
      pnerror ("null char constant");
      pnlval.c = 0;
    }
    SC_POP; I; return CHARACTER;
  }
	YY_BREAK
case 115:
/* rule 115 can match eol */
YY_RULE_SETUP
#line 571 "parser/maria.lex"
lineno++;
	YY_BREAK
case 116:
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 572 "parser/maria.lex"
{
    if (!overflow) {
      pnlval.c = 0, digits = 0, overflow = true; SC_SWITCH (pnchar_oct);
    }
    else
      pnerror ("char constant too large, ignoring `\\'");
  }
	YY_BREAK
case 117:
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 579 "parser/maria.lex"
{
    if (!overflow) {
      pnlval.c = 0, digits = 0, overflow = true; SC_SWITCH (pnchar_hex);
    }
    else
      pnerror ("char constant too large, ignoring `\\x'");
  }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 586 "parser/maria.lex"
{
    if (!overflow) {
      overflow = true;
      switch (pntext[1]) {
      case 'a': pnlval.c = '\a'; break;
      case 'b': pnlval.c = '\b'; break;
      case 't': pnlval.c = '\t'; break;
      case 'n': pnlval.c = '\n'; break;
      case 'v': pnlval.c = '\v'; break;
      case 'f': pnlval.c = '\f'; break;
      case 'r': pnlval.c = '\r'; break;
      default:
	pnlval.c = pntext[1];
      }
    }
    else
      pnerror ("char constant too large");
  }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 604 "parser/maria.lex"
{
    if (!overflow) {
      overflow = true;
      pnlval.c = *pntext;
    }
    else
      pnerror ("char constant too large");
  }
	YY_BREAK
case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 612 "parser/maria.lex"
{
    lineno++;
    pnerror ("unterminated char constant");
    if (!overflow)
      pnlval.c = 0;
    SC_POP; I; return CHARACTER;
  }
	YY_BREAK

case 121:
YY_RULE_SETUP
#line 621 "parser/maria.lex"
{
  (pnlval.c <<= 3) |= *pntext - '0';
  if (++digits >= 3 || (pnlval.c >> (CHAR_T_BIT - 3)))
    SC_SWITCH (pnchar);
}
	YY_BREAK

case 122:
YY_RULE_SETUP
#line 628 "parser/maria.lex"
{
    (pnlval.c <<= 4) |= *pntext - '0';
    if (++digits >= 2)
      SC_SWITCH (pnchar);
  }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 633 "parser/maria.lex"
{
    (pnlval.c <<= 4) |= *pntext - 'a' + 0x0a;
    if (++digits >= 2)
      SC_SWITCH (pnchar);
  }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 638 "parser/maria.lex"
{
    (pnlval.c <<= 4) |= *pntext - 'A' + 0x0a;
    if (++digits >= 2)
      SC_SWITCH (pnchar);
  }
	YY_BREAK


case 125:
/* rule 125 can match eol */
YY_RULE_SETUP
#line 646 "parser/maria.lex"
SC_SWITCH_B (pnchar);
	YY_BREAK

case YY_STATE_EOF(pnchar):
case YY_STATE_EOF(pnchar_oct):
case YY_STATE_EOF(pnchar_hex):
#line 649 "parser/maria.lex"
{
  pnerror ("EOF in char constant"); SC_POP; NEXTBUF;
}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 653 "parser/maria.lex"
{ INITSTR; SC_CALL (pnstring, NAME); }
	YY_BREAK

case 127:
YY_RULE_SETUP
#line 656 "parser/maria.lex"
SC_POP;
	YY_BREAK
case 128:
/* rule 128 can match eol */
YY_RULE_SETUP
#line 657 "parser/maria.lex"
lineno++;
	YY_BREAK
case 129:
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 658 "parser/maria.lex"
{
    character = 0, digits = 0; SC_SWITCH (pnstring_oct);
  }
	YY_BREAK
case 130:
*yy_cp = (yy_hold_char); /* undo effects of setting up pntext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up pntext again */
YY_RULE_SETUP
#line 661 "parser/maria.lex"
{
    character = 0, digits = 0; SC_SWITCH (pnstring_hex);
  }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 664 "parser/maria.lex"

	YY_BREAK
case 132:
YY_RULE_SETUP
#line 665 "parser/maria.lex"
{
    switch (pntext[1]) {
    case 'a': APPEND ('\a'); break;
    case 'b': APPEND ('\b'); break;
    case 't': APPEND ('\t'); break;
    case 'n': APPEND ('\n'); break;
    case 'v': APPEND ('\v'); break;
    case 'f': APPEND ('\f'); break;
    case 'r': APPEND ('\r'); break;
    default:
      APPEND (pntext[1]);
    }
  }
	YY_BREAK
case 133:
/* rule 133 can match eol */
YY_RULE_SETUP
#line 678 "parser/maria.lex"
{ EXTEND; lineno++; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 679 "parser/maria.lex"
EXTEND;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 680 "parser/maria.lex"
{
    pnerror ("string constant terminated by `\\'"); EXTEND; SC_POP;
  }
	YY_BREAK
case YY_STATE_EOF(pnstring):
#line 683 "parser/maria.lex"
{
    pnerror ("EOF in string constant"); SC_POP; NEXTBUF;
  }
	YY_BREAK

case 136:
YY_RULE_SETUP
#line 688 "parser/maria.lex"
{
  (character <<= 3) |= *pntext - '0';
  if (++digits >= 3 || (character >> (CHAR_BIT - 3))) {
    APPEND (character);
    SC_SWITCH (pnstring);
  }
}
	YY_BREAK

case 137:
YY_RULE_SETUP
#line 697 "parser/maria.lex"
{
    (character <<= 4) |= *pntext - '0';
    if (++digits >= 2) {
      APPEND (character);
      SC_SWITCH (pnstring);
    }
  }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 704 "parser/maria.lex"
{
    (character <<= 4) |= *pntext - 'a' + 0x0a;
    if (++digits >= 2) {
      APPEND (character);
      SC_SWITCH (pnstring);
    }
  }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 711 "parser/maria.lex"
{
    (character <<= 4) |= *pntext - 'A' + 0x0a;
    if (++digits >= 2) {
      APPEND (character);
      SC_SWITCH (pnstring);
    }
  }
	YY_BREAK


case 140:
/* rule 140 can match eol */
YY_RULE_SETUP
#line 721 "parser/maria.lex"
{ APPEND (character); SC_SWITCH_B (pnstring); }
	YY_BREAK
case YY_STATE_EOF(pnstring_oct):
case YY_STATE_EOF(pnstring_hex):
#line 722 "parser/maria.lex"
{
    APPEND (character); SC_POP;
    pnerror ("EOF at escaped character in string constant"); NEXTBUF;
  }
	YY_BREAK

case 141:
YY_RULE_SETUP
#line 728 "parser/maria.lex"
{ I; return *pntext; }
	YY_BREAK
case 142:
/* rule 142 can match eol */
YY_RULE_SETUP
#line 729 "parser/maria.lex"
lineno++;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 730 "parser/maria.lex"
pnerror ("unknown character");
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 732 "parser/maria.lex"
NEXTBUF;
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 734 "parser/maria.lex"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2906 "parser/lex.pn.C"
case YY_STATE_EOF(pnname):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed pnin at a new source and called
			 * pnlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = pnin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( pnwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * pntext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of pnlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					pnrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			pnrestart(pnin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 436 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 436 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 435);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					pnrestart(pnin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( pnwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve pntext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void pnrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        pnensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            pn_create_buffer(pnin,YY_BUF_SIZE );
	}

	pn_init_buffer(YY_CURRENT_BUFFER,input_file );
	pn_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void pn_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		pnpop_buffer_state();
	 *		pnpush_buffer_state(new_buffer);
     */
	pnensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	pn_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (pnwrap()) processing, but the only time this flag
	 * is looked at is after pnwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void pn_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	pnin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE pn_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) pnalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in pn_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) pnalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in pn_create_buffer()" );

	b->yy_is_our_buffer = 1;

	pn_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with pn_create_buffer()
 * 
 */
    void pn_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		pnfree((void *) b->yy_ch_buf  );

	pnfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a pnrestart() or at EOF.
 */
    static void pn_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	pn_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then pn_init_buffer was _probably_
     * called from pnrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void pn_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		pn_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void pnpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	pnensure_buffer_stack();

	/* This block is copied from pn_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from pn_switch_to_buffer. */
	pn_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void pnpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	pn_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		pn_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void pnensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)pnalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)pnrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) pnalloc(new_size  );

		else
			(yy_start_stack) = (int *) pnrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR(
			"out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up pntext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		pntext[pnleng] = (yy_hold_char); \
		(yy_c_buf_p) = pntext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		pnleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int pnget_lineno  (void)
{
        
    return pnlineno;
}

/** Get the input stream.
 * 
 */
FILE *pnget_in  (void)
{
        return pnin;
}

/** Get the output stream.
 * 
 */
FILE *pnget_out  (void)
{
        return pnout;
}

/** Get the length of the current token.
 * 
 */
int pnget_leng  (void)
{
        return pnleng;
}

/** Get the current token.
 * 
 */

char *pnget_text  (void)
{
        return pntext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void pnset_lineno (int  line_number )
{
    
    pnlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see pn_switch_to_buffer
 */
void pnset_in (FILE *  in_str )
{
        pnin = in_str ;
}

void pnset_out (FILE *  out_str )
{
        pnout = out_str ;
}

int pnget_debug  (void)
{
        return pn_flex_debug;
}

void pnset_debug (int  bdebug )
{
        pn_flex_debug = bdebug ;
}

/* pnlex_destroy is for both reentrant and non-reentrant scanners. */
int pnlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		pn_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		pnpop_buffer_state();
	}

	/* Destroy the stack itself. */
	pnfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        pnfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
    	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
    	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *pnalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *pnrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void pnfree (void * ptr )
{
	free( (char *) ptr );	/* see pnrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 734 "parser/maria.lex"



void
pnlexreset (void)
{
  lineno = 1;
  filename.create (0);
  overflow = false;
  condlevel = passlevel = 0;
  pass = true;
  SC_FLUSH;
  while (!in.empty ())
    popInclude ();
  yy_init = 1;
  struct yy_buffer_state* b = YY_CURRENT_BUFFER;
  pn_delete_buffer (b);
  if (yy_start_stack) {
    free (yy_start_stack);
    yy_start_stack = 0;
    yy_start_stack_depth = 0;
  }
}

unsigned
pnmsg (void)
{
  unsigned col =
    fprintf (stderr, "%s:%u:", filename.getString (), lineno);
  if (currentTransition)
    col += fprintf (stderr, "transition `%s':", currentTransition->getName ());
  else if (currentPlace)
    col += fprintf (stderr, "place `%s':", currentPlace->getName ());
  return col;
}

void
pnwarn (const char* s)
{
  if (pnwarnings) {
    fprintf (stderr, "%s:%u:Warning:", filename.getString (), lineno);
    if (currentTransition)
      fprintf (stderr, "transition `%s':", currentTransition->getName ());
    else if (currentPlace)
      fprintf (stderr, "place `%s':", currentPlace->getName ());
    fprintf (stderr, "%s\n", s);
  }
}

void
pnerror (const char* s)
{
  fprintf (stderr, "%s:%u:", filename.getString (), lineno);
  if (currentTransition)
    fprintf (stderr, "transition `%s':", currentTransition->getName ());
  else if (currentPlace)
    fprintf (stderr, "place `%s':", currentPlace->getName ());
  fprintf (stderr, "%s\n", s);
  pnerrors++;
}

static bool
popInclude (void)
{
  {
    size_t oldcondlevel = in.empty () ? 0 : in.top ().condlevel;

    if (oldcondlevel < condlevel) {
      pnerror ("too many #if statements");
    }
    else if (oldcondlevel > condlevel) {
      pnerror ("too many #endif statements");
    }
  }

  if (pnin && pnin != stdin) fclose (pnin);

  if (in.empty ()) {
    static const char* lastnetname;
    filename = netname;
    if (lastnetname == netname)
      return pnrestart (0), false;
    else if (!(pnin = openfile (lastnetname = netname))) {
      perror (lastnetname);
      pnerrors++;
      yy_init = 1;
      return pnrestart (0), false;
    }
    else {
      lineno = 1;
      return pnrestart (pnin), true;
    }
  }
  else {
    filename = *in.top ().name;
    lineno = in.top ().lineno;
    delete in.top ().name;
    pn_delete_buffer (YY_CURRENT_BUFFER);
    pn_switch_to_buffer (in.top ().bs);
    in.pop ();
    return true;
  }
}

bool
defined (const char* sym)
{
  for (NameList::const_iterator i = defs.begin (); i != defs.end (); i++)
    if (!strcmp (sym, *i))
      return true;
  return false;
}

void
define_sym (const char* sym)
{
  if (!defined (sym))
    defs.append (newString (sym));
}

void
undef_sym (const char* sym)
{
  for (NameList::iterator i = defs.begin (); i != defs.end (); i++) {
    if (!strcmp (sym, *i)) {
      defs.remove (i);
      return;
    }
  }
}

